@@ -39,6 +39,7 @@
 #include "application.h"
 #include "global.h" 
 #include "version.h" 
+#include "debug.h"
 
 #include <stdio.h> 
 
@@ -74,22 +75,39 @@ char *U61_Application::get_title()
  */
 int U61_Application::main(int argc, char **argv)
 {
+  int retcode=0;
+  
   CL_SetupCore::init();
   CL_SetupCore::init_display();
   CL_SetupCore::init_sound();
   CL_SetupCore::init_network();
 
-  if (U61_Global::game.init(argv[0]))
-    {
-      U61_Global::game.run();
-    }
-  U61_Global::game.deinit();
+  U61_Debug::init();
+  U61_LOG_MESSAGE("Starting...");
 
-  return 0;
+  try
+    {
+      if (U61_Global::game.init(argv[0]))
+        {
+	  U61_LOG_MESSAGE("Init OK!");
+          U61_Global::game.run();
+        }
+      U61_Global::game.deinit();
+    }
+  catch (CL_Error e)
+    {
+      U61_LOG_ERROR("Unhandled error: "<<e.message);
+      retcode=1;
+    }
+
+  U61_LOG_MESSAGE("Game over...");
+  U61_Debug::deinit();
 
   CL_SetupCore::deinit_network();    
   CL_SetupCore::deinit_sound();
   CL_SetupCore::deinit_display();
   CL_SetupCore::deinit();
+
+  return retcode;
 }
 
