@@ -52,8 +52,6 @@ class U61_Application : public CL_ClanApplication
 public:	
     virtual char *get_title();
     virtual int main(int argc, char** argv);
-    virtual void init_modules();
-    virtual void deinit_modules();
 protected:
     char app_name[U61_STRING_SIZE];
 };
