@@ -345,9 +345,9 @@ void U61_Block::draw(int x,int y,int size)
 
 /*--------------------------------------------------------------------------*/
 /*
- * draws the frame of a block onto the screen (used for previsions)
+ * draws the frame of a block onto the screen (used for anticipations)
  */
-void U61_Block::draw_prevision(int x,int y,int size)
+void U61_Block::draw_anticipation(int x,int y,int size)
 {
     int i;
     int x2,y2;
@@ -360,7 +360,7 @@ void U61_Block::draw_prevision(int x,int y,int size)
         {
             x2=x+x2*U61_Global::data.square_w[size];
             y2=y+y2*U61_Global::data.square_h[size];
-            items[i].square.draw_prevision(x2,y2,size);
+            items[i].square.draw_anticipation(x2,y2,size);
         }
     }
 }
