@@ -81,7 +81,7 @@ public:
 
     void draw(int x,int y,int size=U61_Data::SIZE_BIG);
     void draw_preview(int x,int y,int size=U61_Data::SIZE_BIG);
-    void draw_prevision(int x,int y,int size=U61_Data::SIZE_BIG);
+    void draw_anticipation(int x,int y,int size=U61_Data::SIZE_BIG);
     
     static const int MAX_ITEMS=100;
 protected:
