@@ -42,6 +42,8 @@
 #include "clientprotocol.h"
 #include "global.h"
 #include "time.h"
+#include "platform.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -57,7 +59,8 @@
  */
 U61_ClientProtocol::U61_ClientProtocol(U61_ClientDispatcher *d, 
 				       int p,int ch,
-                                       char *id) : U61_Protocol(p,ch)
+                                       char *id)
+  : U61_Protocol(p,ch)
 {
   dispatcher=d;
   server_id=id;
@@ -86,10 +89,12 @@ void U61_ClientProtocol::check_connection()
   int i;
   U61_Player *p;
 
-  if (stage!=CLOSED && game!=NULL && game->receive_game_closed())
+  if (stage!=CLOSED 
+      && game!=NULL 
+      && game->receive_game_closed())
     {
       stage=CLOSED;
-      //cout<<"stage=CLOSED\n";
+      U61_LOG_DEBUG("stage=CLOSED");
       connection->close();
 
       /*
@@ -121,35 +126,35 @@ int U61_ClientProtocol::send_next_packet()
       if ((result=start_searching())==DONE)
 	{
 	  stage=SEARCHING;
-          //cout<<"stage=SEARCHING\n";
+	  U61_LOG_DEBUG("stage=SEARCHING");
 	}
       break;
     case CONNECTED_TO_SERVER:
       if ((result=join_delay())==DONE)
 	{
 	  stage=JOIN_DELAY_ELAPSED;
-	  //cout<<"stage=JOIN_DELAY_ELAPSED\n";
+	  U61_LOG_DEBUG("stage=JOIN_DELAY_ELAPSED");
 	}
       break;
     case CHANNEL_FOUND:
       if ((result=send_id(connection))==DONE)
 	{
 	  stage=ID_SENT;
-          //cout<<"stage=ID_SENT\n";
+	  U61_LOG_DEBUG("stage=ID_SENT");
 	}
       break;
     case ID_RECEIVED:
       if ((result=send_version(connection))==DONE)
 	{
 	  stage=VERSION_SENT;
-          //cout<<"stage=VERSION_SENT\n";
+	  U61_LOG_DEBUG("stage=VERSION_SENT");
 	}
       break;
     case TIME_RECEIVED:
       if ((result=send_ready(connection))==DONE)
 	{
 	  stage=READY_SENT;
-          //cout<<"stage=READY_SENT\n";
+	  U61_LOG_DEBUG("stage=READY_SENT");
 	}
       break;
     case READY_RECEIVED:
@@ -157,10 +162,11 @@ int U61_ClientProtocol::send_next_packet()
       dispatcher->open(connection);
       
       stage=PLAYING;
-      //cout<<"stage=PLAYING\n";
+      U61_LOG_DEBUG("stage=PLAYING");
       
       break;
     }
+
   return result;
 }
 
@@ -180,94 +186,95 @@ int U61_ClientProtocol::recv_next_packet()
       if ((result=connect_to_server())==DONE)
 	{
 	  stage=CONNECTED_TO_SERVER;
-          //cout<<"stage=CONNECTED_TO_SERVER\n";
+	  U61_LOG_DEBUG("stage=CONNECTED_TO_SERVER");
 	}
       break;
     case JOIN_DELAY_ELAPSED:
       if ((result=find_channel())==DONE)
 	{
 	  stage=CHANNEL_FOUND;
-	  //cout<<"stage=CHANNEL_FOUND\n";
+	  U61_LOG_DEBUG("stage=CHANNEL_FOUND");
 	}
       break;
     case ID_SENT:
       if ((result=recv_id(connection))==DONE)
 	{  
-          stage=ID_RECEIVED;
-          //cout<<"stage=ID_RECEIVED\n";
+	  stage=ID_RECEIVED;
+	  U61_LOG_DEBUG("stage=ID_RECEIVED");
 	}
       break;
     case VERSION_SENT:
       if ((result=recv_version(connection))==DONE)
 	{
 	  stage=VERSION_RECEIVED;
-          //cout<<"stage=VERSION_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=VERSION_RECEIVED");
 	}
       break;
     case VERSION_RECEIVED:
       if ((result=recv_script_name())==DONE)
 	{
 	  stage=SCRIPT_NAME_RECEIVED;
-	  //cout<<"stage=SCRIPT_NAME_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=SCRIPT_NAME_RECEIVED");
 	}
       break;
     case SCRIPT_NAME_RECEIVED:
       if ((result=recv_script())==DONE)
 	{
 	  stage=SCRIPT_RECEIVED;
-	  //cout<<"stage=SCRIPT_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=SCRIPT_RECEIVED");
 	}
       break;
     case SCRIPT_RECEIVED:
       if ((result=recv_id0())==DONE)
 	{
 	  stage=ID0_RECEIVED;
-	  //cout<<"stage=ID0_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=ID0_RECEIVED");
 	}
       break;
     case ID0_RECEIVED:
       if ((result=recv_id1())==DONE)
 	{
 	  stage=ID1_RECEIVED;
-	  //cout<<"stage=ID1_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=ID1_RECEIVED");
 	}
       break;
     case ID1_RECEIVED:
       if ((result=recv_initial_speed())==DONE)
 	{
 	  stage=INITIAL_SPEED_RECEIVED;
-	  //cout<<"stage=INITIAL_SPEED_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=INITIAL_SPEED_RECEIVED");
 	}
       break;
     case INITIAL_SPEED_RECEIVED:
       if ((result=recv_acceleration())==DONE)
 	{
 	  stage=ACCELERATION_RECEIVED;
-	  //cout<<"stage=ACCELERATION_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=ACCELERATION_RECEIVED");
 	}
       break;
     case ACCELERATION_RECEIVED:
       if ((result=recv_curse_delay())==DONE)
 	{
 	  stage=CURSE_DELAY_RECEIVED;
-	  //cout<<"stage=CURSE_DELAY_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=CURSE_DELAY_RECEIVED");
 	}
       break;
     case CURSE_DELAY_RECEIVED:
       if ((result=recv_time())==DONE)
 	{
 	  stage=TIME_RECEIVED;
-	  //cout<<"stage=TIME_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=TIME_RECEIVED");
 	}
       break;
     case READY_SENT:
       if ((result=recv_ready(connection))==DONE)
 	{
 	  stage=READY_RECEIVED;
-          //cout<<"stage=READY_RECEIVED\n";
+	  U61_LOG_DEBUG("stage=READY_RECEIVED");
 	}
       break;
     }
+
   return result;
 }
 
@@ -286,11 +293,9 @@ int U61_ClientProtocol::start_searching()
     }
   catch (CL_Error e)
     {
-      cout<<"Find error : "<<e.message<<"\n";
+      U61_LOG_WARNING("Find error : "<<e.message<<"");
     }
 
-  //  cout<<"start searching\n";
-
   return result;
 }
 
@@ -316,17 +321,13 @@ int U61_ClientProtocol::connect_to_server()
               join_delay_start=U61_Time::for_effect();
 	      result=DONE;
 	    }
-          else
-            {
-              cout<<"...\n";
-	    }
 	}
     }
   catch (CL_Error e)
     {
-      cout<<"Connect error : "<<e.message<<"\n";
+      U61_LOG_WARNING("Connect error : "<<e.message<<"");
     }
-  //cout<<"find server\n";
+  U61_LOG_DEBUG("find server");
 
   return result;
 }
@@ -386,10 +387,13 @@ int U61_ClientProtocol::recv_script_name()
 
   if (connection->peek())
     {
-      if (connection->recv(script_name,sizeof(script_name)-1))
+      if (connection->recv(U61_Global::remote_script.name_buffer,
+			   sizeof(U61_Global::remote_script.name_buffer)-1))
 	{
+	  U61_Platform::strip_remote_script_path
+	    (U61_Global::remote_script.name_buffer);
 	  result=DONE;
-          // cout<<"script_name=\""<<script_name<<"\"\n";
+          U61_LOG_DEBUG("script_name=\""<<U61_Global::remote_script.name_buffer<<"\"");
 	}
     }
 
@@ -408,10 +412,10 @@ int U61_ClientProtocol::recv_script()
 
   if (connection->peek())
     {
-      if (connection->recv(script,sizeof(script)-1))
+      if (connection->recv(U61_Global::remote_script.code_buffer,
+			   sizeof(U61_Global::remote_script.code_buffer)-1))
 	{
 	  result=DONE;
-          // cout<<"script=\""<<script<<"\"\n";
 	}
     }
 
@@ -431,7 +435,7 @@ int U61_ClientProtocol::recv_id0()
       if (connection->recv(&id0))
 	{
 	  result=DONE;
-	  //cout<<"id0="<<id0<<"\n";
+	  U61_LOG_DEBUG("id0="<<id0);
 	}
     }
 
@@ -451,7 +455,7 @@ int U61_ClientProtocol::recv_id1()
       if (connection->recv(&id1))
 	{
 	  result=DONE;
-	  //cout<<"id1="<<id1<<"\n";
+	  U61_LOG_DEBUG("id1="<<id1);
 	}
     }
 
@@ -471,7 +475,7 @@ int U61_ClientProtocol::recv_initial_speed()
       if (connection->recv(&initial_speed))
 	{
 	  result=DONE;
-	  //cout<<"initial_speed="<<initial_speed<<"\n";
+	  U61_LOG_DEBUG("initial_speed="<<initial_speed);
 	}
     }
 
@@ -491,7 +495,7 @@ int U61_ClientProtocol::recv_acceleration()
       if (connection->recv(&acceleration))
 	{
 	  result=DONE;
-	  //cout<<"acceleration="<<acceleration<<"\n";
+	  U61_LOG_DEBUG("acceleration="<<acceleration);
 	}
     }
 
@@ -511,7 +515,7 @@ int U61_ClientProtocol::recv_curse_delay()
       if (connection->recv(&curse_delay))
 	{
 	  result=DONE;
-	  //cout<<"curse_delay="<<curse_delay<<"\n";
+	  U61_LOG_DEBUG("curse_delay="<<curse_delay);
 	}
     }
 
@@ -531,7 +535,7 @@ int U61_ClientProtocol::recv_time()
       if (connection->recv(&time))
 	{
 	  result=DONE;
-	  //cout<<"time="<<time<<"\n";
+	  U61_LOG_DEBUG("time="<<time);
 	}
     }
 
@@ -544,7 +548,7 @@ int U61_ClientProtocol::recv_time()
  */
 void U61_ClientProtocol::start_game()
 {
-  U61_Global::game.do_network_join(script,
+  U61_Global::game.do_network_join(U61_Global::remote_script.code_buffer,
 				   id0,id1,
 				   initial_speed,acceleration,curse_delay,
 				   time);
