@@ -64,12 +64,10 @@ class U61_ClientProtocol : public U61_Protocol
 
  protected:
   static const int JOIN_DELAY=100;
-
+  
   char *server_id;
   U61_ClientDispatcher *dispatcher;
   U61_Connection *connection;
-  char script_name[U61_STRING_SIZE];
-  char script[SCRIPT_SIZE];
   int id0;
   int id1;
   int initial_speed;
