@@ -156,55 +156,55 @@ void U61_Config::reset()
 
   player[0].activable=read_player_int(0,ID_ACTIVABLE,true);
   read_player_str(player[0].name,0,ID_NAME,"ufoot");
-  player[0].key_start_stop=read_player_int(0,ID_KEY_START_STOP, CL_KEY_1);
+  player[0].key_start_stop=read_player_int(0,ID_KEY_START_STOP, CL_KEY_F5);
   player[0].key_move_left=read_player_int(0,ID_KEY_MOVE_LEFT, CL_KEY_LEFT);
   player[0].key_move_right=read_player_int(0,ID_KEY_MOVE_RIGHT, CL_KEY_RIGHT);
-  player[0].key_rotate_left=read_player_int(0,ID_KEY_ROTATE_LEFT, CL_KEY_Q);
+  player[0].key_rotate_left=read_player_int(0,ID_KEY_ROTATE_LEFT, CL_KEY_DOWN);
   player[0].key_rotate_right=read_player_int(0,ID_KEY_ROTATE_RIGHT, CL_KEY_UP);
-  player[0].key_move_down=read_player_int(0,ID_KEY_MOVE_DOWN, CL_KEY_DOWN);
-  player[0].key_drop=read_player_int(0,ID_KEY_DROP, CL_KEY_SPACE);
-  player[0].key_next_victim=read_player_int(0,ID_KEY_NEXT_VICTIM, CL_KEY_W);
-  player[0].key_prev_victim=read_player_int(0,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[0].key_use_antidote=read_player_int(0, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
+  player[0].key_move_down=read_player_int(0,ID_KEY_MOVE_DOWN, CL_KEY_ALT);
+  player[0].key_drop=read_player_int(0,ID_KEY_DROP, ' '+CL_NUM_KEYS-32);
+  player[0].key_next_victim=read_player_int(0,ID_KEY_NEXT_VICTIM, CL_KEY_LCTRL);
+  player[0].key_prev_victim=read_player_int(0,ID_KEY_PREV_VICTIM, CL_KEY_LSHIFT);
+  player[0].key_use_antidote=read_player_int(0, ID_KEY_USE_ANTIDOTE, CL_KEY_RCTRL);
 
   player[1].activable=read_player_int(1,ID_ACTIVABLE,true);
   read_player_str(player[1].name,1,ID_NAME,"etoile");
-  player[1].key_start_stop=read_player_int(1,ID_KEY_START_STOP, CL_KEY_1);
+  player[1].key_start_stop=read_player_int(1,ID_KEY_START_STOP, CL_KEY_F6);
   player[1].key_move_left=read_player_int(1,ID_KEY_MOVE_LEFT, CL_KEY_LEFT);
   player[1].key_move_right=read_player_int(1,ID_KEY_MOVE_RIGHT, CL_KEY_RIGHT);
-  player[1].key_rotate_left=read_player_int(1,ID_KEY_ROTATE_LEFT, CL_KEY_Q);
+  player[1].key_rotate_left=read_player_int(1,ID_KEY_ROTATE_LEFT, CL_KEY_DOWN);
   player[1].key_rotate_right=read_player_int(1,ID_KEY_ROTATE_RIGHT, CL_KEY_UP);
-  player[1].key_move_down=read_player_int(1,ID_KEY_MOVE_DOWN, CL_KEY_DOWN);
-  player[1].key_drop=read_player_int(1,ID_KEY_DROP, CL_KEY_SPACE);
-  player[1].key_next_victim=read_player_int(1,ID_KEY_NEXT_VICTIM, CL_KEY_W);
-  player[1].key_prev_victim=read_player_int(1,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[1].key_use_antidote=read_player_int(1, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
+  player[1].key_move_down=read_player_int(1,ID_KEY_MOVE_DOWN, CL_KEY_ALT);
+  player[1].key_drop=read_player_int(1,ID_KEY_DROP, ' '+CL_NUM_KEYS-32);
+  player[1].key_next_victim=read_player_int(1,ID_KEY_NEXT_VICTIM, CL_KEY_LCTRL);
+  player[1].key_prev_victim=read_player_int(1,ID_KEY_PREV_VICTIM, CL_KEY_LSHIFT);
+  player[1].key_use_antidote=read_player_int(1, ID_KEY_USE_ANTIDOTE, CL_KEY_RCTRL);
 
   player[2].activable=read_player_int(2,ID_ACTIVABLE,true);
-  read_player_str(player[2].name,2,ID_NAME,"toto");
-  player[2].key_start_stop=read_player_int(2,ID_KEY_START_STOP, CL_KEY_1);
+  read_player_str(player[2].name,2,ID_NAME,"popol");
+  player[2].key_start_stop=read_player_int(2,ID_KEY_START_STOP, CL_KEY_F7);
   player[2].key_move_left=read_player_int(2,ID_KEY_MOVE_LEFT, CL_KEY_LEFT);
   player[2].key_move_right=read_player_int(2,ID_KEY_MOVE_RIGHT, CL_KEY_RIGHT);
-  player[2].key_rotate_left=read_player_int(2,ID_KEY_ROTATE_LEFT, CL_KEY_Q);
+  player[2].key_rotate_left=read_player_int(2,ID_KEY_ROTATE_LEFT, CL_KEY_DOWN);
   player[2].key_rotate_right=read_player_int(2,ID_KEY_ROTATE_RIGHT, CL_KEY_UP);
-  player[2].key_move_down=read_player_int(2,ID_KEY_MOVE_DOWN, CL_KEY_DOWN);
-  player[2].key_drop=read_player_int(2,ID_KEY_DROP, CL_KEY_SPACE);
-  player[2].key_next_victim=read_player_int(2,ID_KEY_NEXT_VICTIM, CL_KEY_W);
-  player[2].key_prev_victim=read_player_int(2,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[2].key_use_antidote=read_player_int(2, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
+  player[2].key_move_down=read_player_int(2,ID_KEY_MOVE_DOWN, CL_KEY_ALT);
+  player[2].key_drop=read_player_int(2,ID_KEY_DROP, ' '+CL_NUM_KEYS-32);
+  player[2].key_next_victim=read_player_int(2,ID_KEY_NEXT_VICTIM, CL_KEY_LCTRL);
+  player[2].key_prev_victim=read_player_int(2,ID_KEY_PREV_VICTIM, CL_KEY_LSHIFT);
+  player[2].key_use_antidote=read_player_int(2, ID_KEY_USE_ANTIDOTE, CL_KEY_RCTRL);
 
   player[3].activable=read_player_int(3,ID_ACTIVABLE,true);
-  read_player_str(player[3].name,3,ID_NAME,"zorro");
-  player[3].key_start_stop=read_player_int(3,ID_KEY_START_STOP, CL_KEY_1);
+  read_player_str(player[3].name,3,ID_NAME,"arthur");
+  player[3].key_start_stop=read_player_int(3,ID_KEY_START_STOP, CL_KEY_F8);
   player[3].key_move_left=read_player_int(3,ID_KEY_MOVE_LEFT, CL_KEY_LEFT);
   player[3].key_move_right=read_player_int(3,ID_KEY_MOVE_RIGHT, CL_KEY_RIGHT);
-  player[3].key_rotate_left=read_player_int(3,ID_KEY_ROTATE_LEFT, CL_KEY_Q);
+  player[3].key_rotate_left=read_player_int(3,ID_KEY_ROTATE_LEFT, CL_KEY_DOWN);
   player[3].key_rotate_right=read_player_int(3,ID_KEY_ROTATE_RIGHT, CL_KEY_UP);
-  player[3].key_move_down=read_player_int(3,ID_KEY_MOVE_DOWN, CL_KEY_DOWN);
-  player[3].key_drop=read_player_int(3,ID_KEY_DROP, CL_KEY_SPACE);
-  player[3].key_next_victim=read_player_int(3,ID_KEY_NEXT_VICTIM, CL_KEY_W);
-  player[3].key_prev_victim=read_player_int(3,ID_KEY_PREV_VICTIM, CL_KEY_E);
-  player[3].key_use_antidote=read_player_int(3, ID_KEY_USE_ANTIDOTE, CL_KEY_R);
+  player[3].key_move_down=read_player_int(3,ID_KEY_MOVE_DOWN, CL_KEY_ALT);
+  player[3].key_drop=read_player_int(3,ID_KEY_DROP, ' '+CL_NUM_KEYS-32);
+  player[3].key_next_victim=read_player_int(3,ID_KEY_NEXT_VICTIM, CL_KEY_LCTRL);
+  player[3].key_prev_victim=read_player_int(3,ID_KEY_PREV_VICTIM, CL_KEY_LSHIFT);
+  player[3].key_use_antidote=read_player_int(3, ID_KEY_USE_ANTIDOTE, CL_KEY_RCTRL);
 }
 
 /*--------------------------------------------------------------------------*/
