@@ -89,7 +89,7 @@ class U61_Config
 
   int max_fps;
   
-  bool network_prevision;
+  bool network_anticipation;
 
   U61_PlayerConfig player[NB_PLAYERS];
 
@@ -126,7 +126,7 @@ class U61_Config
 
   static char *const ID_MAX_FPS="cfg_max_fps";
 
-  static char *const ID_NETWORK_PREVISION="cfg_network_prevision";
+  static char *const ID_NETWORK_ANTICIPATION="cfg_network_anticipation";
 
   static char *const ID_FIRST_REPEAT_MOVE="first_repeat_move";
   static char *const ID_STANDARD_REPEAT_MOVE="standard_repeat_move";
@@ -135,7 +135,7 @@ class U61_Config
   static char *const ID_FIRST_REPEAT_OTHER="first_repeat_other";
   static char *const ID_STANDARD_REPEAT_OTHER="standard_repeat_other";
 
-  static char *const ID_PREVISION="prevision";
+  static char *const ID_ANTICIPATION="anticipation";
   static char *const ID_ACTIVABLE="playing";
   static char *const ID_NAME="name";
 
@@ -148,7 +148,7 @@ class U61_Config
   static char *const ID_KEY_DROP="key_drop";
   static char *const ID_KEY_NEXT_VICTIM="key_next_victim";
   static char *const ID_KEY_PREV_VICTIM="key_prev_victim";
-  static char *const ID_KEY_USE_ANTEDOTE="key_use_antedote";
+  static char *const ID_KEY_USE_ANTIDOTE="key_use_antidote";
 };
 
 #endif
