@@ -39,6 +39,7 @@
  ---------------------------------------------------------------------------*/
 
 #include "connection.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -59,7 +60,7 @@ U61_Connection::U61_Connection(CL_NetGame *g,CL_NetComputer *c,
   channel=ch;
   opened=true;
 
-  //cout<<"Opening connection on channel "<<ch<<"\n";
+  U61_LOG_DEBUG("Opening connection on channel "<<ch<<"");
 
   group.computers.push_back(c);
 
@@ -73,11 +74,11 @@ U61_Connection::U61_Connection(CL_NetGame *g,CL_NetComputer *c,
 	{
 	  game->set_access(ch,&group,
 			   ACCESS_CHANNEL_READ|ACCESS_CHANNEL_WRITE);
-	  // cout<<"Connection access granted\n";
+	  U61_LOG_DEBUG("Connection access granted");
 	}
       catch (CL_Error e)
 	{
-	  cout<<"Access error : "<<e.message<<"\n";
+	  U61_LOG_WARNING("Access error : "<<e.message<<"");
 	}
     }
 }
@@ -118,7 +119,7 @@ bool U61_Connection::send(U61_Packet *p)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Send error : "<<e.message<<"\n";
+	  U61_LOG_WARNING("Send error : "<<e.message);
 	}
     }
 
@@ -153,7 +154,7 @@ bool U61_Connection::send(char *str,int max)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Send error : "<<e.message<<"\n";
+	  U61_LOG_WARNING("Send error : "<<e.message);
 	}
     }
 
@@ -180,7 +181,7 @@ bool U61_Connection::send(int i)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Send error : "<<e.message<<"\n";
+	  U61_LOG_WARNING("Send error : "<<e.message);
 	}
     }
 
@@ -208,7 +209,7 @@ bool U61_Connection::send(U61_Event evt)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Send error : "<<e.message<<"\n";
+	  U61_LOG_WARNING("Send error : "<<e.message);
 	}
     }
 
@@ -258,7 +259,7 @@ bool U61_Connection::recv(U61_Packet *p)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Receive error : "<<e.message<<"\n";    
+	  U61_LOG_WARNING("Receive error : "<<e.message); 
 	}
     }
 
@@ -297,7 +298,7 @@ bool U61_Connection::recv(char *str,int max)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Receive error : "<<e.message<<"\n";    
+	  U61_LOG_WARNING("Receive error : "<<e.message);
 	}
     }
 
@@ -334,7 +335,7 @@ bool U61_Connection::recv(int *i)
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Receive error : "<<e.message<<"\n";    
+	  U61_LOG_WARNING("Receive error : "<<e.message);
 	}
     }
 
@@ -361,18 +362,18 @@ bool U61_Connection::recv(U61_Event *evt)
 	  if (size!=sizeof(*evt))
 	    {
 	      result=false;
-	      cout<<"Event received with errors\n";
+	      U61_LOG_WARNING("Event size is incorrect");
 	    }
 	  else
 	    {
 	      memcpy(evt,message.data.data(),size);
-	      //cout<<"Event "<<*evt<<" received\n";
+	      U61_LOG_DEBUG("Event "<<*evt<<" received");
 	    }  
 	}
       catch (CL_Error e)
 	{
 	  result=false;
-	  cout<<"Receive error : "<<e.message<<"\n";    
+	  U61_LOG_WARNING("Receive error : "<<e.message);  
 	}
     }
 
