@@ -105,6 +105,7 @@ public:
     CL_SoundBuffer *sound_block_pattern;
     CL_SoundBuffer *sound_player_start;
     CL_SoundBuffer *sound_curse_receive;
+    CL_SoundBuffer *sound_player_loose;
  
     CL_SoundBuffer *mikmod_test;
  
@@ -208,6 +209,7 @@ protected:
     static char *const ID_SOUND_BLOCK_PATTERN="sound/block_pattern";
     static char *const ID_SOUND_PLAYER_START="sound/player_start";
     static char *const ID_SOUND_CURSE_RECEIVE="sound/curse_receive";
+    static char *const ID_SOUND_PLAYER_LOOSE="sound/player_loose";
  
     static char *const ID_SQUARE_BIG="square/big_n";
     static char *const ID_SQUARE_SMALL="square/small_n";
