@@ -41,6 +41,7 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#include "confirmdatamenu.h"
 #include "datafilemenu.h"
 #include "button.h"
 #include "platform.h"
@@ -59,15 +60,14 @@
 /* 
  * creation of the data file menu
  */ 
-U61_DataFileMenu::U61_DataFileMenu(U61_Menu *parent,U61_Config *conf)
+U61_DataFileMenu::U61_DataFileMenu(U61_Menu *parent, U61_Config *conf)
   : U61_FileMenu(parent,"Choose a theme",
-		 U61_Platform::get_data_path(),
-		 U61_Platform::get_user_path(),
+		 U61_Platform::get_builtin_theme_path(),
+		 U61_Platform::get_user_theme_path(),
 		 ".dat",
-		 conf->data_file)
-  
+		 conf->data_file)  
 {
-
+  config=conf;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -78,12 +78,13 @@ U61_Menu *U61_DataFileMenu::validate()
 {
   U61_Menu *next_menu;
 
-  next_menu=this;
-  switch (selection)
-    {
-    case 0:
-      break;
-    }
+  next_menu=new U61_ConfirmDataMenu(this);
 
   return next_menu;
 }
+
+
+
+
+
+
