@@ -41,6 +41,7 @@
  ---------------------------------------------------------------------------*/
 
 #include "eventcopy.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -123,7 +124,7 @@ void U61_EventCopy::put(U61_Event event)
 	}
       else    
 	{
-	  //cout<<"Copying event "<<event<<"\n";
+	  U61_LOG_DEBUG("Copying event "<<event);
 	  queue.push_back(event);
 	}
     }
