@@ -48,6 +48,7 @@
 #include "button.h"
 #include "platform.h"
 #include "const.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -109,7 +110,7 @@ bool U61_FileMenu::add_files(char *dir)
   char buffer_name[U61_STRING_SIZE];
   bool exists=false;
 
-  //cout << "Searching "<<dir<<" for \""<< extension <<"\" files. \n";
+  U61_LOG_DEBUG("Searching "<<dir<<" for \""<<extension<<"\" files.");
   if (U61_Platform::open_dir(dir,extension))
     {
       while ((name=U61_Platform::next_file())!=NULL)
