@@ -88,7 +88,7 @@ U61_Game::U61_Game()
 U61_Game::~U61_Game()
 {
   U61_LOG_DEBUG("Display : "<<calls_to_display);
-  U61_LOG_DEBUG(" Logic : "<<calls_to_logic);
+  U61_LOG_DEBUG("Logic : "<<calls_to_logic);
   U61_LOG_DEBUG("Menu : "<<calls_to_menu); 
   U61_LOG_DEBUG("Poll : "<<calls_to_poll);
   U61_LOG_DEBUG("Poll CL : "<<calls_to_poll_clanlib); 
@@ -142,6 +142,11 @@ bool U61_Game::init(char *filename)
       success=success && U61_Global::data.load2();
     }  
 
+  if (success)
+    {
+      U61_Global::input_monitor.init();
+    }
+
   return success;
 }
 
@@ -298,19 +303,6 @@ void U61_Game::poll()
       calls_to_poll_clanlib++;
 
       u61_time=U61_Time::for_event();
-      /*
-       * this test disables useless polling
-       * polling is done at a maximum rate of 30 / sec
-       */
-      if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
-        {
-	  last_menu_time_polled=clanlib_time;   
-
-	  menu_input.poll(u61_time);
-          menu_input.poll_mouse();
-
-	  calls_to_poll_menu++;     
-        }
       /*
        * this test disables useless polling
        * polling is done at a maximum rate of once per game cycle
@@ -326,6 +318,19 @@ void U61_Game::poll()
 
 	  calls_to_poll_u61++;     
         }
+      /*
+       * this test disables useless polling
+       * polling is done at a maximum rate of 30 / sec
+       */
+      if (last_menu_time_polled<clanlib_time-MENU_POLL_DELAY)
+        {
+	  last_menu_time_polled=clanlib_time;   
+
+	  menu_input.poll(u61_time);
+          menu_input.poll_mouse();
+
+	  calls_to_poll_menu++;     
+        }
     }
   calls_to_poll++;
 }
@@ -371,8 +376,17 @@ void U61_Game::display()
       current_menu->draw();
     }
 
+  /*
+   * It's wise to clean up those things regularly
+   */
   U61_Script::collect_garbage();
 
+  /*
+   * Calling check() avoids keys repeating for ever because of a nasty 
+   * CAPS LOCK related bug.
+   */
+  U61_Global::input_monitor.check();
+
   calls_to_display++;  
 }
 
@@ -427,6 +441,7 @@ void U61_Game::network()
 {
   int i;
   int slot;
+  bool new_player_created=false;
 
   if (protocol!=NULL)
     {
@@ -449,9 +464,19 @@ void U61_Game::network()
               if (slot>=0)
 		{
                   player[slot].init_network(dispatcher,i);
+		  new_player_created=true;
 		}
 	    }
 	}
+      if (new_player_created)
+	{
+	  /*
+	   * It's a good place to put this wav call. Indeed, it will be called
+	   * each time a new player comes on the screen, and here, we can avoid
+	   * playing the same sound 10 times (it sounds ugly).
+	   */
+	  U61_Sound::play_player_start();
+	}
     }
 }
 
@@ -980,14 +1005,4 @@ U61_Player *U61_Game::find_player_by_id(int id)
   return result;
 }
 
-/*--------------------------------------------------------------------------*/
-/*
- * Translates a scan code, used internally to recognize keys, into
- * an ascii code usable in strings. This function is an ugly hack
- * I created because menu_input wasn't accessible from U61_Global...
- */
-int U61_Game::scan_code_to_ascii(int scan_code)
-{
-  return menu_input.get_ascii(scan_code);
-}
 
