@@ -43,6 +43,7 @@
 #include "button.h"
 #include "edit.h"
 #include "global.h"
+#include "savescriptmenu.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -58,11 +59,11 @@
  * creation of the menu
  */ 
 U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
-    : U61_Menu(parent,"Choose your server")
+  : U61_Menu(parent,"Choose your server")
 {
-    add_item(new U61_Button("Join"));
-    add_item(new U61_Edit("Server",U61_Global::config.server_id));
-    select(0);
+  add_item(new U61_Button("Join"));
+  add_item(new U61_Edit("Server",U61_Global::config.server_id));
+  select(0);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -71,17 +72,19 @@ U61_JoinMenu::U61_JoinMenu(U61_Menu *parent)
  */
 U61_Menu *U61_JoinMenu::validate()
 {
-    U61_Menu *next_menu;
+  U61_Menu *next_menu;
+  U61_Menu *save_menu;
 
-    next_menu=this;
+  next_menu=this;
 
-    switch (selection)
+  switch (selection)
     {
     case 0:
-        next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(this));
-        U61_Global::game.start_network_join();
-        break;
+      save_menu=new U61_SaveScriptMenu(this);
+      next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(save_menu));
+      U61_Global::game.start_network_join();
+      break;
     }
 
-    return next_menu;
+  return next_menu;
 }
