@@ -42,6 +42,7 @@
 
 #include "key.h"
 #include "debug.h"
+#include "global.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -115,7 +116,7 @@ void U61_Key::poll(int time)
 {
     bool pressed;
 
-    pressed=CL_Keyboard::get_keycode(code_in);    
+    pressed=U61_Global::input_monitor.is_pressed(code_in);    
 
     if (pressed)
     {
