@@ -189,7 +189,7 @@ void U61_LayoutItem::draw()
 
       if (player->is_active())
 	{
-	  sprintf(buffer,"%6d",player->get_score()/10);
+	  sprintf(buffer,"%6d",player->get_score()/100);
 	  U61_Global::data.font_info[size]->print_left
 	    (x_info+U61_Global::data.offset_score_x[size],
 	     y_info+U61_Global::data.offset_score_y[size],
@@ -223,14 +223,14 @@ void U61_LayoutItem::draw()
 	     buffer);
 
 	  buffer[0]=0;
-	  while (i<4 && i<player->get_nb_antedote())
+	  while (i<4 && i<player->get_nb_antidote())
 	    {
-	      strcat(buffer,U61_Data::SYMBOL_ANTEDOTE);
+	      strcat(buffer,U61_Data::SYMBOL_ANTIDOTE);
 	      ++i;
 	    }
 	  U61_Global::data.font_symbol[size]->print_left
-	    (x_info+U61_Global::data.offset_antedotes_x[size],
-	     y_info+U61_Global::data.offset_antedotes_y[size],
+	    (x_info+U61_Global::data.offset_antidotes_x[size],
+	     y_info+U61_Global::data.offset_antidotes_y[size],
 	     buffer);
 
 	  sprintf(buffer,player->get_curse_name());
