@@ -42,6 +42,7 @@
 #include "letter.h"
 #include "time.h"
 #include "utils.h"
+#include "square.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -58,9 +59,10 @@
  */ 
 U61_Letter::U61_Letter(CL_Font *fnt,char code)
 {
-    set_font(fnt);
-    ascii=code; 
-    disable_dance(); 
+  set_font(fnt);
+  ascii=code; 
+  disable_dance(); 
+  disable_blink();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -78,16 +80,16 @@ U61_Letter::~U61_Letter()
  */
 void U61_Letter::enable_dance()
 {
-    if (!dance_state)
+  if (!dance_state)
     {
-        dance_state=true;
+      dance_state=true;
 
-        last_time=U61_Time::for_effect();
+      last_time=U61_Time::for_effect();
 
-        change_dx();
-        change_dy();
-        change_vx();
-        change_vy();
+      change_dx();
+      change_dy();
+      change_vx();
+      change_vy();
     }
 }
 
@@ -97,10 +99,28 @@ void U61_Letter::enable_dance()
  */
 void U61_Letter::disable_dance()
 {
-    dance_state=false;
+  dance_state=false;
 
-    dx=0;
-    dy=0;
+  dx=0;
+  dy=0;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Enables the "blinking mode" (used for editing strings)
+ */
+void U61_Letter::enable_blink()
+{
+  blink_state=true;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * Disables the "blinking mode" (used for editing strings)
+ */
+void U61_Letter::disable_blink()
+{
+  blink_state=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -109,28 +129,28 @@ void U61_Letter::disable_dance()
  */
 void U61_Letter::compute()
 {
-    int time;
+  int time;
 
-    time=U61_Time::for_effect();
-    while(last_time<time)
+  time=U61_Time::for_effect();
+  while(last_time<time)
     {
-        dx+=vx;
-        dy+=vy;
+      dx+=vx;
+      dy+=vy;
         
-        if (dx<-W_MAX_MOVE||dx>W_MAX_MOVE)
+      if (dx<-W_MAX_MOVE||dx>W_MAX_MOVE)
         {
-            dx-=vx;
-            change_vx();
-//            change_vy();
+	  dx-=vx;
+	  change_vx();
+	  //            change_vy();
         }
-        if (dy<-H_MAX_MOVE||dy>H_MAX_MOVE)
+      if (dy<-H_MAX_MOVE||dy>H_MAX_MOVE)
         {
-            dy-=vy;
-            change_vy();
-//            change_vx();
+	  dy-=vy;
+	  change_vy();
+	  //            change_vx();
         }
 
-        last_time+=SLOW_FACTOR;
+      last_time+=SLOW_FACTOR;
     }    
 }
 
@@ -140,13 +160,13 @@ void U61_Letter::compute()
  */
 void U61_Letter::change_vx()
 {
-    if (vx!=1 && vx!=-1)
+  if (vx!=1 && vx!=-1)
     {
-        vx=1;
+      vx=1;
     }
-    if (U61_Utils::random(2))
+  if (U61_Utils::random(2))
     {
-        vx=-vx;
+      vx=-vx;
     }
 }
 
@@ -156,13 +176,13 @@ void U61_Letter::change_vx()
  */
 void U61_Letter::change_vy()
 {
-    if (vy!=1 && vy!=-1)
+  if (vy!=1 && vy!=-1)
     {
-        vy=1;
+      vy=1;
     }
-    if (U61_Utils::random(2))
+  if (U61_Utils::random(2))
     {
-        vy=-vy;
+      vy=-vy;
     }
 }
 
@@ -172,7 +192,7 @@ void U61_Letter::change_vy()
  */
 void U61_Letter::change_dx()
 {
-    dx=U61_Utils::random(W_MAX_MOVE)-W_MAX_MOVE/2;
+  dx=U61_Utils::random(W_MAX_MOVE)-W_MAX_MOVE/2;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -181,7 +201,7 @@ void U61_Letter::change_dx()
  */
 void U61_Letter::change_dy()
 {
-    dy=U61_Utils::random(H_MAX_MOVE)-H_MAX_MOVE/2;
+  dy=U61_Utils::random(H_MAX_MOVE)-H_MAX_MOVE/2;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -190,9 +210,9 @@ void U61_Letter::change_dy()
  */
 char U61_Letter::operator =(char code)
 {
-    ascii=code;
+  ascii=code;
 
-    return code;
+  return code;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -201,7 +221,7 @@ char U61_Letter::operator =(char code)
  */
 int U61_Letter::get_ascii()
 {
-    return ascii;
+  return ascii;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -210,7 +230,7 @@ int U61_Letter::get_ascii()
  */
 void U61_Letter::set_font(CL_Font *fnt)
 {
-    font=fnt;
+  font=fnt;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -219,16 +239,23 @@ void U61_Letter::set_font(CL_Font *fnt)
  */
 void U61_Letter::draw(int x,int y)
 {
-    char text[2];
+  char text[2];
 
-    text[0]=ascii;
-    text[1]=0;
-
-    if (dance_state)
+  if (blink_state && U61_Square::should_blink())
     {
-        compute();
+      text[0]='_';
     }
-    font->print_center(x+dx,y+dy,text);
+  else
+    {
+      text[0]=ascii;
+    }
+  text[1]=0;
+
+  if (dance_state)
+    {
+      compute();
+    }
+  font->print_center(x+dx,y+dy,text);
 }
 
 /*--------------------------------------------------------------------------*/
@@ -237,14 +264,14 @@ void U61_Letter::draw(int x,int y)
  */
 int U61_Letter::get_height()
 {
-    int height;
+  int height;
 
-    height=font->get_height();
-    if (dance_state)
+  height=font->get_height();
+  if (dance_state)
     {
-        height+=H_MAX_MOVE;
+      height+=H_MAX_MOVE;
     }
-    return height;
+  return height;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -253,17 +280,17 @@ int U61_Letter::get_height()
  */
 int U61_Letter::get_width()
 {
-    char text[2];
-    int width;
+  char text[2];
+  int width;
 
-    text[0]=ascii;
-    text[1]=0;
+  text[0]=ascii;
+  text[1]=0;
 
-    width=font->get_text_width(text);
-    if (dance_state)
+  width=font->get_text_width(text);
+  if (dance_state)
     {
-        width+=W_MAX_MOVE;
+      width+=W_MAX_MOVE;
     }
-    return width;
+  return width;
 }
 
