@@ -44,6 +44,7 @@
 
 #include "localsource.h"
 #include "time.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -169,7 +170,7 @@ void U61_LocalSource::poll_dispatcher()
   while (!dispatcher->empty_in(player))
     {
       evt=dispatcher->get_in(player);
-      //cout<<"Local player receiving event "<<evt<<" from dispatcher\n";
+      U61_LOG_DEBUG("Local player receiving event "<<evt<<" from dispatcher");
       evt.time=U61_Time::for_event();
       put(evt);
     }    
@@ -205,7 +206,7 @@ void U61_LocalSource::send_name(int time)
   char c;
   char *str;
 
-  //cout<<"Sending name "<<name<<"\n";
+  U61_LOG_DEBUG("Sending name "<<name);
 
   str=name;
   
