@@ -43,7 +43,8 @@
 #include "emptymenu.h"
 #include "pausingmenu.h"
 #include "alonemenu.h"
-#include "optionmenu.h"
+#include "playeroptionmenu.h"
+#include "gameoptionmenu.h"
 #include "button.h"
 #include "global.h"
 
@@ -65,7 +66,8 @@ U61_MainMenu::U61_MainMenu(U61_Menu *parent)
 {
     add_item(new U61_Button("Quick start"));
     add_item(new U61_Button("Start new game"));
-    add_item(new U61_Button("Change Options"));
+    add_item(new U61_Button("Game Options"));
+    add_item(new U61_Button("Player Options"));
     add_item(new U61_Button("About U61"));
     add_item(new U61_Button("Quit"));
     select(0);
@@ -91,12 +93,15 @@ U61_Menu *U61_MainMenu::validate()
         next_menu=new U61_StartMenu(this);
         break;
     case 2:
-        next_menu=new U61_OptionMenu(this);
+        next_menu=new U61_GameOptionMenu(this);
         break;
     case 3:
-        next_menu=new U61_AboutMenu(this);
+        next_menu=new U61_PlayerOptionMenu(this);
         break;
     case 4:
+        next_menu=new U61_AboutMenu(this);
+        break;
+    case 5:
         next_menu=parent_menu;
         break;
     }
