@@ -1579,6 +1579,11 @@ void U61_Map::stabilize_block()
  */
 void U61_Map::loose()
 {
+  if (!silent)
+    {
+      U61_Sound::play_player_loose();
+    }
+
   U61_LOG_DEBUG("The game is lost");
 
   begin();
@@ -1783,6 +1788,10 @@ void U61_Map::do_curse(U61_Event evt)
       evt.par-=MAX_CURSE_ID;
       U61_LOG_DEBUG("Do remote curse "<<evt);
       U61_Script::do_curse(this,&block,evt.par,true);
+      if (!silent)
+	{
+	  U61_Sound::play_curse_receive();
+	}
     }
   /*
    * The call to check_block is very important since do_curse
