@@ -97,9 +97,9 @@ public:
     void cancel_curse(int i);
     int get_oldest_curse();
     int get_nb_curse();
-    int get_nb_antedote();
-    void add_antedote();
-    void delete_antedote();
+    int get_nb_antidote();
+    void add_antidote();
+    void delete_antidote();
 
     int get_curse_x();
     int get_curse_y();
@@ -115,7 +115,7 @@ public:
 
     void draw(int x,int y, 
               int size=U61_Data::SIZE_BIG,
-              bool prev=false);
+              bool anti=false);
 
     void mute();
 
@@ -123,8 +123,8 @@ public:
     void set_active(int time);
     void set_inactive();
 
-    void set_prevision_state(bool state);
-    bool get_prevision_state();
+    void set_anticipation_state(bool state);
+    bool get_anticipation_state();
 
     void set_preview_state(bool state);
     bool get_preview_state();
@@ -146,17 +146,19 @@ public:
     static const int WIDTH=10;
     static const int HEIGHT=25;
     static const int NAME_SIZE=8;
-    static const int NB_GLOBAL=100;
-    static const int MAX_CURSE_ID=10000;
+    static const int NB_GLOBAL=1000;
+    static const int MAX_CURSE_ID=1000;
     static const int SPEED_SCALE=1000;
     static const int ACCEL_SCALE=100000;
     static const int TIME_CALLBACK_DELAY=10;
     static const int CHECK_TARGET_DELAY=100;
+    static const int CHECK_CURSE_DELAY=100;
     static const int ANTICIPATE_MAX=1000;
     static const int MAX_USER_SPEED=20;
     static const int MAX_USER_ACCEL=10;
     static const int MAX_SYSTEM_SPEED=50;
     static const int MAX_SYSTEM_ACCEL=15;
+    static const int MAX_SCORE=100000000;
 protected:
     static const int speeds[MAX_SYSTEM_SPEED+1];
     static const int accels[MAX_SYSTEM_ACCEL+1];
@@ -164,7 +166,7 @@ protected:
     U61_Square squares[WIDTH][HEIGHT];
     U61_Block block;
     U61_Block next_block;
-    U61_Block block_prevision;
+    U61_Block block_anticipation;
     list<U61_Event> auto_events;
     list<U61_Event> request_events;
     int global_val[NB_GLOBAL];
@@ -191,14 +193,16 @@ protected:
     int best_score;
     int games;
     int match_count;
-    bool prevision_state;
+    bool anticipation_state;
     bool preview_state;
     int curse_x;
     int curse_y;
     bool curse_state;
+    bool curse_chosen;
+    bool curse_asked;
     int curse_id;
     int curse_counter;
-    int nb_antedote;
+    int nb_antidote;
 
     void compute_next();
     void update_speed();
@@ -206,7 +210,7 @@ protected:
     void put_auto_event(U61_Event event);
     void put_request_event(U61_Event event);
 
-    void draw_prevision(int x,int y, int size=U61_Data::SIZE_BIG);
+    void draw_anticipation(int x,int y, int size=U61_Data::SIZE_BIG);
 
     void block_rotate_left();
     void block_rotate_right();
@@ -218,7 +222,7 @@ protected:
     void next_victim(U61_Event *event);
     void set_victim(int id);
     void name_add_letter(char c);
-    void use_antedote();
+    void use_antidote();
 
     bool is_block_active();
     bool is_block_ok(U61_Block *test);
@@ -239,7 +243,12 @@ protected:
     void request_curse(U61_Event event);
     void do_curse(U61_Event event);
 
+    void check_curse();
     void check_target();
+    void check_block();
 };
 
 #endif
+
+
+
