@@ -82,18 +82,6 @@ int U61_Menu::bottom_message_width=-1000000;
  */
 bool U61_Menu::shaded=false;
 
-/*--------------------------------------------------------------------------*/
-/*
- * This is an ugly hack. Indeed, some menus (for instance "save script")
- * are initialized long before they are displayed. In fact they appear
- * only when the user presses back. And sometimes they have been initialized
- * with outdated values, therefore a call to update on each item is required.
- * This boolean is set to true each time a menu is deleted, and it fixes
- * the problem since when it is true, the active menu (which has not been
- * deleted yet) calls update on each item.
- */
-bool U61_Menu::force_update=false;
-
 /*---------------------------------------------------------------------------
  functions
  ---------------------------------------------------------------------------*/
@@ -123,8 +111,6 @@ U61_Menu::~U61_Menu()
     {
       delete items[i];
     }
-
-  force_update=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -238,19 +224,6 @@ void U61_Menu::draw()
 
   nb_item=items.size();
 
-  /*
-   * If force_update is set to true we refresh the content of every
-   * menu item. This an ugly hack to prevent refresh bugs.
-   */
-  if (force_update)
-    {
-      for (i=0;i<nb_item;++i)
-	{
-	  items[i]->update();
-	}
-      force_update=false;
-    }
-
   if (shaded)
     {
       U61_Global::data.shade->put_screen(0,0);
