@@ -38,23 +38,15 @@ public:
     ~U61_MenuInput();
  
     void init();
-    char get_ascii(int code);
-    char *get_label(int code);
 
     void poll_mouse();
     int get_mouse_y();
 
 protected:
-    void set_menu_key(int i,int cl_code,int ascii,char *label);
-
     const static int MOUSE_DELAY=50;
-    const static int NB_KEYS=100;
     const static int REPEAT_FIRST=50;
     const static int REPEAT_STANDARD=15;
 
-    char *keys_label[NB_KEYS];
-    char keys_ascii[NB_KEYS];
-
     int mouse_last_fired;
     int mouse_y;
 };
