@@ -120,6 +120,13 @@ void U61_MenuItem::draw(int y)
   int last_letter_width2;
   int letter_width;
 
+  /*
+   * The update is forced here because blinking cursors require it,
+   * and in a general manner, nasry bugs can happen if there are not
+   * enough updates. Should not be so slow however...
+   */
+  update();
+
   x=U61_Global::data.screen_w/2;
   x-=get_width()/2;
 
@@ -184,6 +191,16 @@ int U61_MenuItem::get_width()
 void U61_MenuItem::select_char(int i)
 {
   text[i].enable_dance();
+  selected=true;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * make a letter in the current menu item blink 
+ */
+void U61_MenuItem::blink_char(int i)
+{
+  text[i].enable_blink();
 }
 
 /*--------------------------------------------------------------------------*/
@@ -224,7 +241,9 @@ void U61_MenuItem::unselect()
   for (i=0;i<nb_letter;++i)
     {
       text[i].disable_dance();
+      text[i].disable_blink();
     }
+  selected=false;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -233,17 +252,38 @@ void U61_MenuItem::unselect()
  */
 void U61_MenuItem::set_text(char *str)
 {
-  text.clear();
+  char old[U61_STRING_SIZE];
+
   /*
-   * we fill the vector of letters with the chars of the string
-   * passed in arg, this will simply create a menu item that
-   * display the string
+   * Before we empty the queue of letters and refill it with some new,
+   * we check up that this is needed, ie the strings are not the same
+   * if they are the same, it's no use to bother, and moreover it can
+   * become a bug since the dancing letters don't behave correctly
    */
-  while(*str)
+  put_text(old);
+  if (strcmp(str,old)!=0)
     {
-      text.push_back(U61_Letter(U61_Global::data.font_menu,*str));
-      str++;
-    } 
+      text.clear();
+      /*
+       * we fill the vector of letters with the chars of the string
+       * passed in arg, this will simply create a menu item that
+       * display the string
+       */
+      while(*str)
+	{
+	  text.push_back(U61_Letter(U61_Global::data.font_menu,*str));
+	  str++;
+	} 
+      /*
+       * This is not useless, it just means if the item is selected, we
+       * have to re-apply the effects of the selection since emptying
+       * the queue has cancelled everything...
+       */
+      if (selected)
+	{
+	  select();
+	}
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -289,3 +329,4 @@ bool U61_MenuItem::is_mouse_in(int y)
 
   return ok;
 }
+
