@@ -42,6 +42,7 @@
 
 #include "music.h"
 #include "global.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -66,8 +67,6 @@ void U61_Music::test()
 
 //    CL_SoundBuffer_Session *session=NULL;
 
-//    cout<<"Test de MikMod lance\n";
-
 //    session=new CL_SoundBuffer_Session(U61_Global::data.mikmod_test->prepare());
 
 //    U61_Global::data.mikmod_test->play();
