@@ -61,6 +61,9 @@ class U61_Platform
   static char *get_user_theme_path();
   static char *get_user_script_path();
   static char *get_config_file();
+
+  static void strip_remote_script_path(char *path);
+  static void unstrip_remote_script_path(char *path);
     
   static bool open_dir(char *dir,char *ext="");
   static char *next_file();
@@ -69,6 +72,13 @@ class U61_Platform
   static bool create_user_dir(); 
 
   static void exec(char *file);
+
+  static void open_log_files();
+  static void close_log_files();
+  static void log_to_error_file(char *text);
+  static void log_to_warning_file(char *text);
+  static void log_to_message_file(char *text);
+  static void log_to_debug_file(char *text,char *file,int line);
  protected:
     
 };
