@@ -203,7 +203,7 @@ char *U61_Platform::get_config_file()
   static char buffer[U61_STRING_SIZE]; 
 
   strcpy (buffer,get_user_path());
-  strcat(buffer,"config");
+  strcat(buffer,"config.lua");
  
   return buffer;
 }
