@@ -88,7 +88,7 @@ class U61_Player
   int get_best_score();
   U61_Block get_next_block();
   int get_nb_curse();
-  int get_nb_antedote();
+  int get_nb_antidote();
   char *get_curse_name();
 
   void init_local(U61_Input *input,
@@ -121,7 +121,7 @@ class U61_Player
   U61_Map last;
   U61_Map sure;
 
-  bool *prevision;
+  bool *anticipation;
 
   void handle_event(U61_Event *evt);
   void start(int time);
