@@ -107,8 +107,8 @@ void U61_PlayerInput::init(U61_PlayerConfig *config)
                       U61_Event::PREV_VICTIM,
                       config->first_repeat_other,
                       config->standard_repeat_other));
-    set_key(9,U61_Key(config->key_use_antedote,
-                      U61_Event::USE_ANTEDOTE,
+    set_key(9,U61_Key(config->key_use_antidote,
+                      U61_Event::USE_ANTIDOTE,
                       config->first_repeat_other,
                       config->standard_repeat_other));
 }
