@@ -68,7 +68,7 @@ U61_PlayerMenu::U61_PlayerMenu(U61_Menu *parent,
     add_item(new U61_Edit("Name",config->name));
     add_item(new U61_Button("Key settings"));
     add_item(new U61_Button("Advanced key settings"));
-    add_item(new U61_Toggle("Prevision mode is",&(config->prevision),
+    add_item(new U61_Toggle("Anticipation mode is",&(config->anticipation),
                             "on","off"));
     select(0);
 }
