@@ -51,6 +51,7 @@
 #include "script.h"
 #include "const.h"
 #include "utils.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -104,7 +105,7 @@ bool U61_Script::do_string(char *str)
       bSuccess=true;
       break;
     default:
-      cout<<"Lua error reading script, code is "<<iResult<<".\n";
+      U61_LOG_WARNING("Lua error reading script, code is "<<iResult<<".");
       break;
     }
 
@@ -123,7 +124,7 @@ bool U61_Script::do_file(char *name)
   bSuccess=false;
 
   //lua_open();
-  //cout<<"Loading script from \""<<name<<"\".\n";
+  U61_LOG_DEBUG("Loading script from \""<<name<<"\".");
   iResult=CL_Lua::dofile(name);
   switch (iResult)
     {
@@ -131,7 +132,7 @@ bool U61_Script::do_file(char *name)
       bSuccess=true;
       break;
     default:
-      cout<<"Lua error reading script, code is "<<iResult<<".\n";
+      U61_LOG_WARNING("Lua error reading script, code is "<<iResult<<".");
       break;
     }
 
@@ -196,10 +197,10 @@ void U61_Script::collect_garbage()
 {
   /*  lua_Object poped;
 
-  while (!lua_isnil(poped=lua_pop()))
-  {
-    cout<<"Popping\n";
-    }*/
+      while (!lua_isnil(poped=lua_pop()))
+      {
+      U61_LOG_DEBUG("Popping lua object");
+      }*/
 
   lua_collectgarbage(0);
 }
@@ -616,7 +617,7 @@ int U61_Script::new_curse(U61_Map *m,U61_Block *b)
  * Calls the Lua script function taht performs the action linked to a curse
  * This is were most of the curse effects should be coded
  */
-void U61_Script::do_curse(U61_Map *m,int id,bool sent)
+void U61_Script::do_curse(U61_Map *m,U61_Block *b,int id,bool sent)
 {
   CL_LuaObject func;
   CL_LuaObject obj;
@@ -626,8 +627,11 @@ void U61_Script::do_curse(U61_Map *m,int id,bool sent)
 
   secure_pointers();
   current_map=m;
+  current_block=b;
   map_read=true;
   map_write=true;
+  block_read=true;
+  block_write=true;
 
   //  lua_pushnumber(x);
   //  lua_pushnumber(y);
@@ -644,9 +648,9 @@ void U61_Script::do_curse(U61_Map *m,int id,bool sent)
 /*--------------------------------------------------------------------------*/
 /*
  * calls the user defined function that should be called when using an 
- * antedote
+ * antidote
  */
-void U61_Script::use_antedote(U61_Map *m)
+void U61_Script::use_antidote(U61_Map *m,U61_Block *b)
 {
   CL_LuaObject func;
   char command[U61_STRING_SIZE];
@@ -654,11 +658,14 @@ void U61_Script::use_antedote(U61_Map *m)
 
   secure_pointers();
   current_map=m;
+  current_block=b;
   map_read=true;
   map_write=true;
+  block_read=true;
+  block_write=true;
 
   sprintf(arguments,"()");
-  strcpy(command,LUA_USE_ANTEDOTE);
+  strcpy(command,LUA_USE_ANTIDOTE);
   strcat(command,arguments);
   lua_beginblock();
   CL_Lua::dostring(command);
@@ -699,7 +706,7 @@ char *U61_Script::get_curse_name(U61_Map *m,int id)
       str=lua_getstring(ret);
       if(str==NULL)
 	{
-	  cout<<"Curse name is non-string\n";
+	  U61_LOG_WARNING("Curse name is non-string");
 	}
     }
 
@@ -731,7 +738,7 @@ static void return_lua_int(int ret)
     }
   else
     {
-      cout<<"Error returning lua int\n";
+      U61_LOG_WARNING("Error returning lua int");
     }
 }
 
@@ -1118,22 +1125,22 @@ static void set_global()
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it returns the prevision state, ie if the prevision is to be seen
+ * it returns the anticipation state, ie if the anticipation is to be seen
  */
-static void get_prevision_state()
+static void get_anticipation_state()
 {
   if (current_map!=NULL && map_read)
     {
-      return_lua_int (current_map->get_prevision_state() ? 1 : 0);
+      return_lua_int (current_map->get_anticipation_state() ? 1 : 0);
     }
 }
 
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it sets the prevision state, ie if the prevision is to be seen
+ * it sets the anticipation state, ie if the anticipation is to be seen
  */
-static void set_prevision_state()
+static void set_anticipation_state()
 {
   int state;
 
@@ -1141,7 +1148,7 @@ static void set_prevision_state()
     {
       state=CL_Lua::getparam(1);
 
-      current_map->set_prevision_state(state);
+      current_map->set_anticipation_state(state);
     }
 }
 
@@ -1415,39 +1422,39 @@ static void get_nb_curses()
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it returns the number of antedotes available
+ * it returns the number of antidotes available
  */
-static void get_nb_antedotes()
+static void get_nb_antidotes()
 {
   if (current_map!=NULL && map_read)
     {
-      return_lua_int(current_map->get_nb_antedote());
+      return_lua_int(current_map->get_nb_antidote());
     }
 }
 
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it adds an antedote
+ * it adds an antidote
  */
-static void add_antedote()
+static void add_antidote()
 {
   if (current_map!=NULL && map_write)
     {
-      current_map->add_antedote();
+      current_map->add_antidote();
     }
 }
 
 /*--------------------------------------------------------------------------*/
 /*
  * this function is accessible from lua script 
- * it deletes an antedote
+ * it deletes an antidote
  */
-static void delete_antedote()
+static void delete_antidote()
 {
   if (current_map!=NULL && map_write)
     {
-      current_map->delete_antedote();
+      current_map->delete_antidote();
     }
 }
 
@@ -1481,8 +1488,8 @@ void U61_Script::record_all()
   CL_Lua::record(C_ADD_SCORE,add_score);
   CL_Lua::record(C_GET_GLOBAL,get_global);
   CL_Lua::record(C_SET_GLOBAL,set_global);
-  CL_Lua::record(C_GET_PREVISION_STATE,get_prevision_state);
-  CL_Lua::record(C_SET_PREVISION_STATE,set_prevision_state);
+  CL_Lua::record(C_GET_ANTICIPATION_STATE,get_anticipation_state);
+  CL_Lua::record(C_SET_ANTICIPATION_STATE,set_anticipation_state);
   CL_Lua::record(C_GET_PREVIEW_STATE,get_preview_state);
   CL_Lua::record(C_SET_PREVIEW_STATE,set_preview_state);
   CL_Lua::record(C_BLOW_UP_SQUARE,blow_up_square);
@@ -1500,9 +1507,9 @@ void U61_Script::record_all()
   CL_Lua::record(C_CANCEL_CURSE,cancel_curse);
   CL_Lua::record(C_GET_OLDEST_CURSE,get_oldest_curse);
   CL_Lua::record(C_GET_NB_CURSES,get_nb_curses);
-  CL_Lua::record(C_GET_NB_ANTEDOTES,get_nb_antedotes);
-  CL_Lua::record(C_ADD_ANTEDOTE,add_antedote);
-  CL_Lua::record(C_DELETE_ANTEDOTE,delete_antedote);
+  CL_Lua::record(C_GET_NB_ANTIDOTES,get_nb_antidotes);
+  CL_Lua::record(C_ADD_ANTIDOTE,add_antidote);
+  CL_Lua::record(C_DELETE_ANTIDOTE,delete_antidote);
 }
 
 
