@@ -79,8 +79,8 @@ public:
     static void time_callback(U61_Map *m,U61_Block *b);
     static void square_blown_up(U61_Map *m,int x,int y);
     static int new_curse(U61_Map *m,U61_Block *b);
-    static void do_curse(U61_Map *m,int id,bool sent);
-    static void use_antedote(U61_Map *m);
+    static void do_curse(U61_Map *m,U61_Block *b,int id,bool sent);
+    static void use_antidote(U61_Map *m,U61_Block *b);
     static char *get_curse_name(U61_Map *m,int id);
 
     static char *const LUA_NEW_SHAPE="user_new_shape";
@@ -96,7 +96,7 @@ public:
     static char *const LUA_SQUARE_BLOWN_UP="user_square_blown_up";
     static char *const LUA_NEW_CURSE="user_new_curse";
     static char *const LUA_DO_CURSE="user_do_curse";
-    static char *const LUA_USE_ANTEDOTE="user_use_antedote";
+    static char *const LUA_USE_ANTIDOTE="user_use_antidote";
     static char *const LUA_GET_CURSE_NAME="user_get_curse_name";
 
     static char *const C_RESET_BLOCK="u61_reset_block";
@@ -123,8 +123,8 @@ public:
     static char *const C_ADD_SCORE="u61_add_score";
     static char *const C_GET_GLOBAL="u61_get_global";
     static char *const C_SET_GLOBAL="u61_set_global";
-    static char *const C_GET_PREVISION_STATE="u61_get_prevision_state";
-    static char *const C_SET_PREVISION_STATE="u61_set_prevision_state";
+    static char *const C_GET_ANTICIPATION_STATE="u61_get_anticipation_state";
+    static char *const C_SET_ANTICIPATION_STATE="u61_set_anticipation_state";
     static char *const C_GET_PREVIEW_STATE="u61_get_preview_state";
     static char *const C_SET_PREVIEW_STATE="u61_set_preview_state";
     static char *const C_BLOW_UP_SQUARE="u61_blow_up_square";
@@ -142,9 +142,9 @@ public:
     static char *const C_CANCEL_CURSE="u61_cancel_curse";
     static char *const C_GET_OLDEST_CURSE="u61_get_oldest_curse";
     static char *const C_GET_NB_CURSES="u61_get_nb_curses";
-    static char *const C_GET_NB_ANTEDOTES="u61_get_nb_antedotes";
-    static char *const C_ADD_ANTEDOTE="u61_add_antedote";
-    static char *const C_DELETE_ANTEDOTE="u61_delete_antedote";
+    static char *const C_GET_NB_ANTIDOTES="u61_get_nb_antidotes";
+    static char *const C_ADD_ANTIDOTE="u61_add_antidote";
+    static char *const C_DELETE_ANTIDOTE="u61_delete_antidote";
 
 protected:
     static void secure_pointers();
