@@ -62,8 +62,8 @@
  */ 
 U61_ScriptFileMenu::U61_ScriptFileMenu(U61_Menu *parent,U61_Config *conf)
   : U61_FileMenu(parent,"Pick up a script file",
-		 U61_Platform::get_data_path(),
-		 U61_Platform::get_user_path(),
+		 U61_Platform::get_builtin_script_path(),
+		 U61_Platform::get_user_script_path(),
 		 ".lua",
 		 conf->script_file)
 {
