@@ -77,7 +77,8 @@ class U61_ServerProtocol : public U61_Protocol
   const static int ID1_SENT=41;
   const static int INITIAL_SPEED_SENT=42;
   const static int ACCELERATION_SENT=43;
-  const static int TIME_SENT=44;
+  const static int CURSE_DELAY_SENT=44;
+  const static int TIME_SENT=45;
 
   int start_listening();
   int accept_client();    
@@ -88,6 +89,7 @@ class U61_ServerProtocol : public U61_Protocol
   int send_id1();
   int send_initial_speed();
   int send_acceleration();
+  int send_curse_delay();
   int send_time();
 
   void handle_error(int result);
