@@ -39,7 +39,7 @@
 
 #include "startmenu.h"
 #include "button.h"
-#include "emptymenu.h"
+#include "nonpausingmenu.h"
 #include "pausingmenu.h"
 #include "joinmenu.h"
 #include "alonemenu.h"
@@ -66,7 +66,7 @@ U61_StartMenu::U61_StartMenu(U61_Menu *parent)
 {
   add_item(new U61_Button("Play Alone"));
   add_item(new U61_Button("Local Multiplayer Game"));
-  add_item(new U61_Button("New Network Game"));
+  add_item(new U61_Button("Create Network Game"));
   add_item(new U61_Button("Join Network Game"));
   add_item(new U61_Button("Choose players"));
 
@@ -93,7 +93,7 @@ U61_Menu *U61_StartMenu::validate()
       U61_Global::game.start_local_multiplayer();
       break;
     case 2:
-      next_menu=new U61_EmptyMenu(new U61_NetworkMenu(this));
+      next_menu=new U61_NonPausingMenu(new U61_NetworkMenu(this));
       U61_Global::game.start_network_new();
       break;
     case 3:
