@@ -40,6 +40,7 @@
  ---------------------------------------------------------------------------*/
 
 #include "time.h"
+#include "debug.h"
 
 /*---------------------------------------------------------------------------
  variants
@@ -355,5 +356,5 @@ int U61_Time::system_time()
 void U61_Time::idle()
 {
   CL_System::sleep(IDLE_DELAY);
-  //  cout<<"sleep "<<CL_System::get_time()<<"\n";
+  U61_LOG_DEBUG("game is idle");
 }
